/*
 * Copyright (c) 2022, SHANGHAI FUDAN MICROELECTRONICS GROUP CO., LTD.(FUDAN MICROELECTRONICS./ FUDAN MICRO.)
 * All rights reserved.
 *
 * Processor:                   FM33LE0xxA
 * http:                        http://www.fmdevelopers.com.cn/
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * 3. Neither the name of the copyright holder nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * 4. To provide the most up-to-date information, the revision of our documents 
 *    on the World Wide Web will be the most Current. Your printed copy may be  
 *    an earlier revision. To verify you have the latest information avaliable,
 *    refer to: http://www.fmdevelopers.com.cn/.
 *
 * THIS SOFTWARE IS PROVIDED BY FUDAN MICRO "AS IS" AND ANY EXPRESSED 
   ORIMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES 
   OF MERCHANTABILITY NON-INFRINGEMENT AND FITNESS FOR A PARTICULAR PURPOSE
   ARE DISCLAIMED.IN NO EVENT SHALL FUDAN MICRO OR ITS CONTRIBUTORS BE LIABLE 
   FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL 
   DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS 
   OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
   CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
   OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISINGIN ANY WAY OUT OF THE 
   USE OF THIS SOFTWARE, EVEN IF ADVISED OFTHE POSSIBILITY OF SUCH DAMAGE.
*/
#ifndef __APP_H
#define __APP_H
/* Includes ------------------------------------------------------------------*/
#include "main.h"
#include "lin.h"

/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
/* Private macro -------------------------------------------------------------*/
#define APP_START_ADDR             ((uint32_t)0x00008000)/* APP程序起始地址 */
#define APP_EXE_FLAG_ADDR          ((uint32_t)0x00004000)/* APP程序运行标志存储地址，该标志在APP程序中写入和擦除 */
/* 固件类型值定义 */
#define FW_TYPE_BOOT     0x55
#define FW_TYPE_APP      0xAA
/* 定义当前固件类型为APP */
#define FW_TYPE         FW_TYPE_APP
/* 定义数据收发的帧ID，必须跟上位机配置一致 否则无法正常工作 */
/* 定义数据收发帧ID类型，0-标准帧，1-扩展帧 */
#define MSG_ID_TYPE         0
#if (MSG_ID_TYPE == 0)   /* 标准帧 */
/* 对于CAN总线，数据收发ID可以定义为一个ID，也可以定义为不同ID */
    #define MSG_RECEIVE_ID      0x3C
    #define MSG_SEND_ID         0x3D
#else /* 扩展帧 */
/* 对于CAN总线，数据收发ID可以定义为一个ID，也可以定义为不同ID */
    #define MSG_RECEIVE_ID      0x12345
    #define MSG_SEND_ID         0x12346
#endif

#define FW_INFO_MAJOR     0x00  //固件版本号 Major
#define FW_INFO_MINOR     0x00  //固件版本号 Minor
#define FW_INFO_REVISION  0x00  //固件版本号 Revision
#define FW_INFO_BUILD     0x02  //固件版本号 Build     修改此版本号并观察led变化 1-PC0 2-PD12 其他-PB15


/* 定义节点广播地址 */
#define NAD_BROADCAST           0x7F
/* BOOT命令定义 */
#define CMD_GET_FW_INFO         0x80
#define CMD_ENTER_BOOT          0xC1
#define CMD_ERASE_APP           0x42
#define CMD_SET_ADDR_OFFSET     0x03
#define CMD_TRAN_DATA           0xC4
#define CMD_WRITE_DATA          0x85
#define CMD_ENTER_APP           0x06
/* BOOT错误定义 */
#define BOOT_ERR_SUCCESS        0   /* 没有错误 */
#define BOOT_ERR_ERASE          1   /* 固件擦除错误 */
#define BOOT_ERR_ERASE_IN_APP   2   /* 当前模式为app，不能擦除固件 */
#define BOOT_ERR_WRITE_OUTRANGE 3   /* 当前地址超出了正常地址范围 */
#define BOOT_ERR_WRITE_IN_APP   4   /* 当前模式不能写入固件数据 */
#define BOOT_ERR_WRITE          5   /* 数据写入程序存储器出错 */
#define BOOT_ERR_WRITE_OUT_ADDR 6   /* 数据长度超出了地址范围 */
#define BOOT_ERR_TRAN_CRC       7   /* 数据传输CRC校验出错 */
#define BOOT_ERR_WRITE_CRC      8   /* 数据写入芯片CRC校验出错 */
/* Private variables ---------------------------------------------------------*/
extern BootRxMsg BOOT_RxMessage;
extern volatile uint8_t BootRxMsgFlag;/* 接收到数据后的标志 */
/* Private function prototypes -----------------------------------------------*/
/* Private functions ---------------------------------------------------------*/
uint32_t GetSector(uint32_t Address);
FLASH_Status CAN_BOOT_ErasePage(uint32_t StartPageAddr, uint32_t EndPageAddr);
uint16_t CAN_BOOT_GetAddrData(void);
void BOOT_ExecutiveCommand(BootRxMsg *pRxMessage);
void BOOT_JumpToApplication(__IO uint32_t Addr);
FLASH_Status BOOT_ProgramDatatoFlash(uint32_t StartAddress, uint8_t *pData, uint32_t DataNum);
void BOOT_Configuration(void);
uint8_t BOOT_SendData(uint8_t *data, uint8_t len);
uint8_t GetNAD(void);
#endif
/*********************************END OF FILE**********************************/

