/*
 * Copyright (c) 2022, SHANGHAI FUDAN MICROELECTRONICS GROUP CO., LTD.(FUDAN MICROELECTRONICS./ FUDAN MICRO.)
 * All rights reserved.
 *
 * Processor:                   FM33LE0xxA
 * http:                        http://www.fmdevelopers.com.cn/
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * 3. Neither the name of the copyright holder nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * 4. To provide the most up-to-date information, the revision of our documents 
 *    on the World Wide Web will be the most Current. Your printed copy may be  
 *    an earlier revision. To verify you have the latest information avaliable,
 *    refer to: http://www.fmdevelopers.com.cn/.
 *
 * THIS SOFTWARE IS PROVIDED BY FUDAN MICRO "AS IS" AND ANY EXPRESSED 
   ORIMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES 
   OF MERCHANTABILITY NON-INFRINGEMENT AND FITNESS FOR A PARTICULAR PURPOSE
   ARE DISCLAIMED.IN NO EVENT SHALL FUDAN MICRO OR ITS CONTRIBUTORS BE LIABLE 
   FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL 
   DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS 
   OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
   CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
   OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISINGIN ANY WAY OUT OF THE 
   USE OF THIS SOFTWARE, EVEN IF ADVISED OFTHE POSSIBILITY OF SUCH DAMAGE.
*/
/* Includes ------------------------------------------------------------------*/
#include "main.h"
#include "app.h"
/* Private typedef -----------------------------------------------------------*/
typedef  void (*pFunction)(void);
BootRxMsg BOOT_RxMessage;
volatile uint8_t BootRxMsgFlag;//接收到数据后的标志
/* Private define ------------------------------------------------------------*/

/* Base address of the Flash sectors */
#if defined FM33LE0XXA
    #define PAGE_SIZE                         (0x800)    /* 2 Kbytes */
    #define FLASH_SIZE                        (0x20000)  /* 256 KBytes */
#else
    #error "Please select first the FMSH device to be used"
#endif
/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
/* Private function prototypes -----------------------------------------------*/
/* Private functions ---------------------------------------------------------*/

/**
  * @brief  FLASH页擦除
  * @param  页地址
  * @retval None
  */
static FLASH_Status FLASH_ErasePage(uint32_t Page_Address)
{
    if (FL_FAIL == FL_FLASH_SectorErase(FLASH, Page_Address))
    {
        return FLASH_BUSY;
    }
    else
    {
        return FLASH_COMPLETE;
    }
}

/**
  * @brief  FLASH字写入
  * @param  Address写入地址
  * @param  Data写入数据
  * @retval None
  */
static FLASH_Status FLASH_ProgramWord(uint32_t Address, uint32_t Data)
{
    if (FL_FAIL == FL_FLASH_Program_Word(FLASH, Address, Data))
    {
        return FLASH_BUSY;
    }
    else
    {
        return FLASH_COMPLETE;
    }
}

/**
  * @brief  将数据烧写到指定地址的FLASH中
  * @param  Address Flash起始地址
  * @param  Data 数据存储区起始地址
  * @param  DataNum 数据字节数
  * @retval 数据烧写状态
  */
FLASH_Status BOOT_ProgramDatatoFlash(uint32_t StartAddress, uint8_t *pData, uint32_t DataNum)
{
    FLASH_Status FLASHStatus = FLASH_COMPLETE;

    uint32_t i;

    if (StartAddress < APP_EXE_FLAG_ADDR)
    {
        return FLASH_ERROR_PG;
    }
    /* Clear All pending flags */
    /* WRPRTERR 写保护错误 */
    FL_FLASH_ClearFlag_AuthenticationError(FLASH);
    /* FLASH_FLAG_PGERR 编程错误 */
    FL_FLASH_ClearFlag_KeyError(FLASH);
    FL_FLASH_ClearFlag_ClockError(FLASH);
    /* EOP编程和擦除结束 */
    FL_FLASH_ClearFlag_ProgramComplete(FLASH);
    FL_FLASH_ClearFlag_EraseComplete(FLASH);

    if(DataNum%4 != 0)
    {
        DataNum+=(4-(DataNum%4));
    }
    for (i = 0; i < (DataNum >> 2); i++)
    {
        FLASHStatus = FLASH_ProgramWord(StartAddress, *((uint32_t *)pData));
        if (FLASHStatus == FLASH_COMPLETE)
        {
            StartAddress += 4;
            pData += 4;
        }
        else
        {
            return FLASHStatus;
        }
    }
    return  FLASHStatus;
}
/**
  * @brief  擦除指定扇区区间的FLASH数据
  * @param  StartPage 起始扇区地址
  * @param  EndPage 结束扇区地址
  * @retval 扇区擦除状态
  */
FLASH_Status BOOT_ErasePage(uint32_t StartPageAddr, uint32_t EndPageAddr)
{
    uint32_t i;
    FLASH_Status FLASHStatus = FLASH_COMPLETE;

    FLASH_Unlock();
    /* WRPRTERR 写保护错误 */
    FL_FLASH_ClearFlag_AuthenticationError(FLASH);
    /* FLASH_FLAG_PGERR 编程错误 */
    FL_FLASH_ClearFlag_KeyError(FLASH);
    FL_FLASH_ClearFlag_ClockError(FLASH);
    /* EOP编程和擦除结束 */
    FL_FLASH_ClearFlag_ProgramComplete(FLASH);
    FL_FLASH_ClearFlag_EraseComplete(FLASH);

    for (i = StartPageAddr; i <= EndPageAddr; i += PAGE_SIZE)
    {
        FLASHStatus = FLASH_ErasePage(i);
        if (FLASHStatus != FLASH_COMPLETE)
        {
            FLASH_Lock();
            return    FLASHStatus;
        }
    }
    FLASH_Lock();
    return FLASHStatus;
}

/**
  * @brief  升级配置CAN/LIN
  * @param  None
  * @retval None
  */
void BOOT_Configuration(void)
{

    lin_init();

}


/**
  * @brief  BOOT程序发送数据
  * @param  data数据地址
  * @param  len数据长度
  * @retval None
  */
uint8_t BOOT_SendData(uint8_t *data, uint8_t len)
{

    return lin_SendData(data, len);

}

/**
  * @brief  获取BOOT节点地址，该函数根据自己的实际情况进行修改
  * @param  None
  * @retval 节点地址
  */
uint8_t GetNAD(void)
{
    uint8_t NAD = 0x12;
    /* 根据芯片唯一序号来合成一个NAD */
    uint8_t i, mcu_id[12];

    NAD = 0;
    memcpy(mcu_id, (uint8_t *)0x1FFFFA10, 12);
    for (i = 0; i < 12; i++)
    {
        NAD += mcu_id[i];
    }

    if (NAD == 0)
    {
        NAD = 0x12;
    }

    return NAD & 0x7F;
}

/**
  * @brief  控制程序跳转到指定位置开始执行
  * @param  Addr 程序执行地址
  * @retval 程序跳转状态
  */
void BOOT_JumpToApplication(__IO uint32_t Addr)
{
    pFunction Jump_To_Application;
    __IO uint32_t JumpAddress;
    /* Test if user code is programmed starting from address "ApplicationAddress" */
    if (((*(__IO uint32_t *)Addr) & 0x2FFE0000) == 0x20000000)
    {
        /* Jump to user application */
        JumpAddress = *(__IO uint32_t *)(Addr + 4);
        Jump_To_Application = (pFunction) JumpAddress;
        /* 关闭全局中断 */
        __set_PRIMASK(1);
        /* Initialize user application's Stack Pointer */
        __set_MSP(*(__IO uint32_t *)Addr);
        Jump_To_Application();
    }
}


/**
  * @brief  执行主机下发的命令
  * @param  pRxMessage xxx总线消息
  * @retval None
  */
void BOOT_ExecutiveCommand(BootRxMsg *pRxMessage)
{
    uint8_t SendData[8];
    uint8_t PCI = pRxMessage->Data[1];
    uint8_t SID = 0xFF;
    uint8_t CMD = 0xFF;
    /* 根据消息获取SID和NID */
    if ((PCI & 0xF0) == 0x00)
    {
        SID = pRxMessage->Data[2];
        CMD = pRxMessage->Data[3];
    }
    else if ((PCI & 0xF0) == 0x10)
    {
        SID = pRxMessage->Data[3];
        CMD = pRxMessage->Data[4];
    }
    /* 填充NAD */
    SendData[0] = GetNAD();
    /* 解析命令 */
    switch (CMD)
    {
    case CMD_GET_FW_INFO:
        SendData[1] = 0x06;
        SendData[2] = SID + 0x40;
        SendData[3] = FW_TYPE;
        SendData[4] = FW_INFO_MAJOR;/* 固件版本号 Major */
        SendData[5] = FW_INFO_MINOR;/* 固件版本号 Minor */
        SendData[6] = FW_INFO_REVISION;/* 固件版本号 Revision */
        SendData[7] = FW_INFO_BUILD;//* 固件版本号 Build */
        BOOT_SendData(SendData, 8);
        break;
    case CMD_ENTER_BOOT:
        /* 在BOOT程序中不需要执行任何操作，在APP程序中则需要擦除APP运行标志后跳转到BOOT执行或者软件复位程序 */
        FLASH_Unlock();
        /* 擦除写入到FLASH中的APP执行标志，复位运行后，即可执行bootloader程序 */
        BOOT_ErasePage(APP_EXE_FLAG_ADDR, APP_EXE_FLAG_ADDR);
        FLASH_Lock();
        /* 关闭所有中断 */
        __set_PRIMASK(1);
        NVIC_SystemReset();
        break;
    case CMD_ERASE_APP:
        /* APP中不能执行擦除APP的操作 */
        SendData[1] = 0x06;
        SendData[2] = SID + 0x40;
        SendData[3] = BOOT_ERR_ERASE_IN_APP;
        SendData[4] = 0xFF;
        SendData[5] = 0xFF;
        SendData[6] = 0xFF;
        SendData[7] = 0xFF;
        BOOT_SendData(SendData, 8);
        break;
    case CMD_SET_ADDR_OFFSET:
        SendData[1] = 0x06;
        SendData[2] = SID + 0x40;
        SendData[3] = BOOT_ERR_WRITE_IN_APP;
        SendData[4] = 0xFF;
        SendData[5] = 0xFF;
        SendData[6] = 0xFF;
        SendData[7] = 0xFF;
        BOOT_SendData(SendData, 8);
        break;
    case CMD_TRAN_DATA:
        break;
    case CMD_WRITE_DATA:
        SendData[1] = 0x06;
        SendData[2] = SID + 0x40;
        SendData[3] = BOOT_ERR_WRITE_IN_APP;
        SendData[4] = 0xFF;
        SendData[5] = 0xFF;
        SendData[6] = 0xFF;
        SendData[7] = 0xFF;
        BOOT_SendData(SendData, 8);
        break;
    case CMD_ENTER_APP:
        break;
    default:
        break;
    }
}
/*********************************END OF FILE**********************************/

