/*
 * Copyright (c) 2022, SHANGHAI FUDAN MICROELECTRONICS GROUP CO., LTD.(FUDAN MICROELECTRONICS./ FUDAN MICRO.)
 * All rights reserved.
 *
 * Processor:                   FM33LE0xxA
 * http:                        http://www.fmdevelopers.com.cn/
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * 3. Neither the name of the copyright holder nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * 4. To provide the most up-to-date information, the revision of our documents 
 *    on the World Wide Web will be the most Current. Your printed copy may be  
 *    an earlier revision. To verify you have the latest information avaliable,
 *    refer to: http://www.fmdevelopers.com.cn/.
 *
 * THIS SOFTWARE IS PROVIDED BY FUDAN MICRO "AS IS" AND ANY EXPRESSED 
   ORIMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES 
   OF MERCHANTABILITY NON-INFRINGEMENT AND FITNESS FOR A PARTICULAR PURPOSE
   ARE DISCLAIMED.IN NO EVENT SHALL FUDAN MICRO OR ITS CONTRIBUTORS BE LIABLE 
   FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL 
   DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS 
   OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
   CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
   OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISINGIN ANY WAY OUT OF THE 
   USE OF THIS SOFTWARE, EVEN IF ADVISED OFTHE POSSIBILITY OF SUCH DAMAGE.
*/
#include "main.h"
#include "svd.h"


static void SVD_SVS_GPIO_Init(void)
  
{
    FL_GPIO_InitTypeDef         GPIO_InitStruct = {0};
    
    /* Ϊģ⹦ PA15 SVS*/
    GPIO_InitStruct.pin        = FL_GPIO_PIN_15;
    GPIO_InitStruct.mode       = FL_GPIO_MODE_ANALOG;
    GPIO_InitStruct.outputType = FL_GPIO_OUTPUT_PUSHPULL;
    GPIO_InitStruct.pull       = FL_DISABLE;
    GPIO_InitStruct.remapPin   = FL_DISABLE;

    FL_GPIO_Init( GPIOA, &GPIO_InitStruct );
}


/**
  * @brief  SVDʼ
  * @param  void
  * @retval void
  */
void SVD_Init(SVD_MONTIOR_POWER eSVD_MonitroPower, uint32_t u32WarnThreshold, uint32_t u32RevVoltage)
{
    FL_SVD_InitTypeDef    SVD_InitStruct;

    if (SVD_MONTIOR_SVS == eSVD_MonitroPower)
    {   /* SVSųʼΪģ⹦ */
        SVD_SVS_GPIO_Init();
    }
  
    SVD_InitStruct.workMode         = FL_SVD_WORK_MODE_CONTINUOUS;     /* SVDʹ */
    SVD_InitStruct.enablePeriod     = FL_SVD_ENABLE_PERIOD_1000MS;     /* ЪʹµļЪʱ */
    SVD_InitStruct.referenceVoltage = u32RevVoltage;                   /* ο׼ѹ */
    SVD_InitStruct.warningThreshold = u32WarnThreshold;                /* ֵλ */
    SVD_InitStruct.digitalFilter    = FL_ENABLE;                       /* ˲ */
    SVD_InitStruct.SVSChannel       = (FL_FunState)(SVD_MONTIOR_SVS == eSVD_MonitroPower);                      /* SVSͨ */
    FL_SVD_Init(SVD, &SVD_InitStruct);
    
    /* ʹSVD */
    FL_SVD_Enable(SVD);
    /* SVDʹܺȶҪ100usʱ */
    FL_DelayUs(300);
}


/**
  * @brief  SVDSVDO־λѯ
            SVDʵʱѹ־˲
  * @param  void
  * @retval None
  */
SVD_RESULT SVD_SVDO_POLL(void)
{
    /* SVDʵʱѹ־д˼Ĵ */
    return (SVD_RESULT)(SVD_ISR_SVDO_Msk == FL_SVD_GetCurrentPowerStatus(SVD));
}


/**
  * @brief  SVDSVDR־ѯ
            ˲ʹʱ壬˲ź 
  * @param  void
  * @retval None
  */
SVD_RESULT SVD_SVDR_POLL(void)
{
    /* SVDڲ˲ĵѹ־ʹ˲ʱ壻д˼Ĵ */
    return (SVD_RESULT)(SVD_ISR_SVDR_Msk == FL_SVD_GetLatchedPowerStatus(SVD));
}


/**
  * @brief  ȷSVDǷĿ״̬
  * @param  eSVDResultTypeҪȷϵĿ״̬SVD_BELOW_THRESHOLDSVD_HIGHER_THRESHOLD
            u32Delay_us   ʱλus
  * @retval bool   true ǰSVDĿ״̬һ
                   falseǰSVDĿ״̬һ
  */
bool SVD_Result_Confirmed(SVD_RESULT eSVDResultType, uint32_t u32Delay_us)
{
    if (0 == u32Delay_us)
    {
        u32Delay_us += 1;
    }
    /* עǷʹ˲òͬĽѯ */
    while ((SVD_SVDR_POLL() == eSVDResultType) && u32Delay_us)
    {
        if (--u32Delay_us)
        {
            FL_DelayUs(1);
        }
    }
    
    return (bool)(0 == u32Delay_us);
}


