
/*
 * Copyright (c) 2022, SHANGHAI FUDAN MICROELECTRONICS GROUP CO., LTD.(FUDAN MICROELECTRONICS./ FUDAN MICRO.)
 * All rights reserved.
 *
 * Processor:                   FM33LE0xxA
 * http:                        http://www.fmdevelopers.com.cn/
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * 3. Neither the name of the copyright holder nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * 4. To provide the most up-to-date information, the revision of our documents 
 *    on the World Wide Web will be the most Current. Your printed copy may be  
 *    an earlier revision. To verify you have the latest information avaliable,
 *    refer to: http://www.fmdevelopers.com.cn/.
 *
 * THIS SOFTWARE IS PROVIDED BY FUDAN MICRO "AS IS" AND ANY EXPRESSED 
   ORIMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES 
   OF MERCHANTABILITY NON-INFRINGEMENT AND FITNESS FOR A PARTICULAR PURPOSE
   ARE DISCLAIMED.IN NO EVENT SHALL FUDAN MICRO OR ITS CONTRIBUTORS BE LIABLE 
   FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL 
   DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS 
   OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
   CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
   OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISINGIN ANY WAY OUT OF THE 
   USE OF THIS SOFTWARE, EVEN IF ADVISED OFTHE POSSIBILITY OF SUCH DAMAGE.
*//* Includes ------------------------------------------------------------------*/
#include "main.h"
#include "lin.h"
#include "string.h"
#include "crc16.h"
#include "bootloader.h"

/* Private typedef -----------------------------------------------------------*/
typedef  void (*pFunction)(void);
volatile uint8_t BOOT_MsgIndex = 0;
BootRxMsg BOOT_RxMessage[2];
volatile uint8_t BootRxMsgFlag = 0; 

/* Private define ------------------------------------------------------------*/

/* Base address of the Flash sectors */
#if defined FM33LE0XXA
    #define PAGE_SIZE                         (0x800)    /* 2 Kbytes */
    #define FLASH_SIZE                        (0x40000)  /* 256 KBytes */
#else
    #error "Please select first the FMSH device to be used"
#endif
/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
/* Private function prototypes -----------------------------------------------*/
/* Private functions ---------------------------------------------------------*/

static FLASH_Status FLASH_ErasePage(uint32_t Page_Address)
{
    if (FL_FAIL == FL_FLASH_SectorErase(FLASH, Page_Address))
    {
        return FLASH_BUSY;
    }
    else
    {
        return FLASH_COMPLETE;
    }
}

static FLASH_Status FLASH_ProgramWord(uint32_t Address, uint32_t Data)
{
    if (FL_FAIL == FL_FLASH_Program_Word(FLASH, Address, Data))
    {
        return FLASH_BUSY;
    }
    else
    {
        return FLASH_COMPLETE;
    }
}

void BOOT_Configuration(void)
{

    lin_init();

}

uint8_t BOOT_SendData(uint8_t *data, uint8_t len)
{

    return lin_SendData(data, len);

}

/**
  * @brief  ȡBootڵַúԼʵ޸
  * @param  None
  * @retval ڵַ
  */
uint8_t GetNAD(void)
{
    uint8_t NAD = 0x12;
    //оƬΨһϳһNAD
    uint8_t i, mcu_id[12];

    NAD = 0;
    memcpy(mcu_id, (uint8_t *)0x1FFFFA10, 12);
    for (i = 0; i < 12; i++)
    {
        NAD += mcu_id[i];
    }

    if (NAD == 0)
    {
        NAD = 0x12;
    }

    return NAD & 0x7F;
}

/**
  * @brief  дַָFlash 
  * @param  Address Flashʼַ
  * @param  Data ݴ洢ʼַ
  * @param  DataNum ֽ
  * @retval д״̬
  */
FLASH_Status BOOT_ProgramDatatoFlash(uint32_t StartAddress, uint8_t *pData, uint32_t DataNum)
{
    FLASH_Status FLASHStatus = FLASH_COMPLETE;

    uint32_t i;

    if (StartAddress < APP_EXE_FLAG_ADDR)
    {
        return FLASH_ERROR_PG;
    }
    /* Clear All pending flags */
    FL_FLASH_ClearFlag_AuthenticationError(FLASH);//WRPRTERR д
    FL_FLASH_ClearFlag_KeyError(FLASH);//FLASH_FLAG_PGERR ̴
    FL_FLASH_ClearFlag_ClockError(FLASH);
    FL_FLASH_ClearFlag_ProgramComplete(FLASH);//EOP ͱ̽
    FL_FLASH_ClearFlag_EraseComplete(FLASH);

    if(DataNum%4 != 0)
    {
        DataNum+=(4-(DataNum%4));
    }
    for (i = 0; i < (DataNum >> 2); i++)
    {
        FLASHStatus = FLASH_ProgramWord(StartAddress, *((uint32_t *)pData));
        if (FLASHStatus == FLASH_COMPLETE)
        {
            StartAddress += 4;
            pData += 4;
        }
        else
        {
            return FLASHStatus;
        }
    }
    return    FLASHStatus;
}
/**
  * @brief  ָFlash 
  * @param  StartPage ʼַ
  * @param  EndPage ַ
  * @retval ״̬
  */
FLASH_Status BOOT_ErasePage(uint32_t StartPageAddr, uint32_t EndPageAddr)
{
    uint32_t i;
    FLASH_Status FLASHStatus = FLASH_COMPLETE;

    FLASH_Unlock();
    FL_FLASH_ClearFlag_AuthenticationError(FLASH);//WRPRTERR д
    FL_FLASH_ClearFlag_KeyError(FLASH);//FLASH_FLAG_PGERR ̴
    FL_FLASH_ClearFlag_ClockError(FLASH);
    FL_FLASH_ClearFlag_ProgramComplete(FLASH);//EOP ͱ̽
    FL_FLASH_ClearFlag_EraseComplete(FLASH);

    for (i = StartPageAddr; i <= EndPageAddr; i += PAGE_SIZE)
    {
        FLASHStatus = FLASH_ErasePage(i);
        if (FLASHStatus != FLASH_COMPLETE)
        {
            FLASH_Lock();
            return    FLASHStatus;
        }
    }
    FLASH_Lock();
    return FLASHStatus;
}

//Ӳָʼ״̬
void BOOT_HW_DeInit(void)
{
    FL_GPIO_DeInit(LED0_GPIO, LED0_PIN);
}

/**
  * @brief  Ƴתָλÿʼִ 
  * @param  Addr ִеַ
  * @retval ת״̬
  */
void BOOT_JumpToApplication(uint32_t Addr)
{
    static pFunction Jump_To_Application;
    __IO uint32_t JumpAddress;

    BOOT_HW_DeInit();

    /* Test if user code is programmed starting from address "ApplicationAddress" */
    if (((*(__IO uint32_t *)Addr) & 0x2FFE0000) == 0x20000000)
    {
        /* Jump to user application */
        JumpAddress = *(__IO uint32_t *)(Addr + 4);
        Jump_To_Application = (pFunction) JumpAddress;
        __set_PRIMASK(1);//رж
        /* Initialize user application's Stack Pointer */
        __set_MSP(*(__IO uint32_t *)Addr);
        Jump_To_Application();
    }
}


/**
  * @brief  ִ·
  * @param  pRxMessage xxxϢ
  * @retval 
  */
void BOOT_ExecutiveCommand(BootRxMsg *pRxMessage)
{
    uint8_t SendData[8];
    uint8_t ret, i;
    uint8_t *pData;
    uint8_t PCI = pRxMessage->Data[1];
    uint8_t SID = 0xFF;
    uint8_t CMD = 0xFF;
    static uint8_t OLD_CMD = 0xFF;
    uint16_t crc_data;
    static uint8_t CF_Index = 1;
    static uint32_t start_addr = APP_START_ADDR;
    static uint32_t data_size = 0;
    static uint32_t data_index = 0;
    static uint32_t addr_offset = 0;
    __align(4) static uint8_t data_temp[1024];
#if ENCRYPT
    const char *pKey = "123456789abcdefggdfrthfgdfgefsse";
    static uint8_t chainCipherBlock[16] = {0};
    static uint8_t encrypt_init_flag = 0;
#endif
    //ϢȡSIDCMD
    if ((PCI & 0xF0) == 0x00)
    {
        SID = pRxMessage->Data[2];
        CMD = pRxMessage->Data[3];
    }
    else if ((PCI & 0xF0) == 0x10)
    {
        SID = pRxMessage->Data[3];
        CMD = pRxMessage->Data[4];
    }
    SendData[0] = GetNAD();//NAD
    //
    switch (CMD)
    {
    case CMD_GET_FW_INFO:
        OLD_CMD = CMD_GET_FW_INFO;
        SendData[1] = 0x06;
        SendData[2] = SID + 0x40;
        SendData[3] = FW_TYPE;
        SendData[4] = 0;//̼汾 Major
        SendData[5] = 0;//̼汾 Minor
        SendData[6] = 0;//̼汾 Revision
        SendData[7] = 1;//̼汾 Build
        BOOT_SendData(SendData, 8);
        break;
    case CMD_ENTER_BOOT:
        OLD_CMD = CMD_ENTER_BOOT;
        //BOOTвҪִκβAPPҪAPPб־תBOOTִлλ
        if (FW_TYPE == FW_TYPE_APP)
        {
            FLASH_Unlock();
            BOOT_ErasePage(APP_EXE_FLAG_ADDR, APP_EXE_FLAG_ADDR); //д뵽FlashеAPPִб־λк󣬼ִBootloader
            FLASH_Lock();
            __set_PRIMASK(1);//رж
            NVIC_SystemReset();
        }
        break;
    case CMD_ERASE_APP:
        OLD_CMD = CMD_ERASE_APP;
        if (FW_TYPE == FW_TYPE_APP) //APPвִвAPPĲ
        {
            SendData[1] = 0x06;
            SendData[2] = SID + 0x40;
            SendData[3] = BOOT_ERR_ERASE_IN_APP;
        }
        else
        {
            uint32_t EraseSize = (pRxMessage->Data[4] << 24) | (pRxMessage->Data[5] << 16) | (pRxMessage->Data[6] << 8) | (pRxMessage->Data[7] << 0);
            SendData[1] = 0x06;
            SendData[2] = SID + 0x40;
            __set_PRIMASK(1);
            FLASH_Unlock();
            ret = BOOT_ErasePage(APP_EXE_FLAG_ADDR, APP_START_ADDR + EraseSize);
            FLASH_Lock();
            __set_PRIMASK(0);
            if (ret == FLASH_COMPLETE)
            {
                SendData[3] = BOOT_ERR_SUCCESS;
            }
            else
            {
                SendData[3] = BOOT_ERR_ERASE;
            }
        }
        SendData[4] = 0xFF;
        SendData[5] = 0xFF;
        SendData[6] = 0xFF;
        SendData[7] = 0xFF;
        BOOT_SendData(SendData, 8);
        break;
    case CMD_SET_ADDR_OFFSET:
        OLD_CMD = CMD_SET_ADDR_OFFSET;
        SendData[1] = 0x06;
        SendData[2] = SID + 0x40;
        if (FW_TYPE == FW_TYPE_APP)
        {
            SendData[3] = BOOT_ERR_WRITE_IN_APP;
            SendData[4] = 0xFF;
            SendData[5] = 0xFF;
            SendData[6] = 0xFF;
            SendData[7] = 0xFF;
        }
        else
        {
            data_size = 0;
            data_index = 0;
            addr_offset = (pRxMessage->Data[4] << 24) | (pRxMessage->Data[5] << 16) | (pRxMessage->Data[6] << 8) | (pRxMessage->Data[7] << 0);
            start_addr = addr_offset + APP_START_ADDR;
            if (start_addr < APP_START_ADDR)
            {
                SendData[3] = BOOT_ERR_WRITE_OUTRANGE;
            }
            else
            {
                uint16_t buffer_len = sizeof(data_temp);
                SendData[3] = BOOT_ERR_SUCCESS;
                SendData[4] = buffer_len >> 8;
                SendData[5] = buffer_len & 0xFF;
                SendData[6] = 0xFF;
                SendData[7] = 0xFF;
            }
        }
        BOOT_SendData(SendData, 8);
        break;
    case CMD_TRAN_DATA:
        OLD_CMD = CMD_TRAN_DATA;
        if ((OLD_CMD == CMD_TRAN_DATA) || (OLD_CMD == CMD_SET_ADDR_OFFSET))
        {
            if ((PCI & 0xF0) == 0x00)
            {
                data_size = (PCI & 0xF) - 2;
                pData = &pRxMessage->Data[4];
                while (data_index < data_size)
                {
                    data_temp[data_index++] = *pData++;
                }
            }
            else if ((PCI & 0xF0) == 0x10)
            {
                CF_Index = 1;
                data_size = (((PCI & 0xF) << 8) | pRxMessage->Data[2]) - 2;
                pData = &pRxMessage->Data[5];
                for (i = 0; i < 3; i++)
                {
                    data_temp[data_index++] = *pData++;
                }
            }
        }
        break;
    case CMD_WRITE_DATA:
        OLD_CMD = CMD_WRITE_DATA;
        SendData[1] = 0x06;
        SendData[2] = SID + 0x40;
        if (FW_TYPE == FW_TYPE_APP)
        {
            SendData[3] = BOOT_ERR_WRITE_IN_APP;
            SendData[4] = 0xFF;
            SendData[5] = 0xFF;
            SendData[6] = 0xFF;
            SendData[7] = 0xFF;
        }
        else
        {
            crc_data = (pRxMessage->Data[4] << 8) | (pRxMessage->Data[5] << 0);
            if ((data_size != data_index) || (crc_data != crc16_ccitt(data_temp, data_index)))
            {
                SendData[3] = BOOT_ERR_TRAN_CRC;
            }
            else
            {
#if ENCRYPT
                if (!encrypt_init_flag)
                {
                    for (i = 0; i < sizeof(AES_Key_Table); i++)
                    {
                        if (pKey[i] != '\0')
                        {
                            AES_Key_Table[i] = pKey[i];
                        }
                        else
                        {
                            break;
                        }
                    }
                    aesDecInit();//ִнܳʼ֮ǰΪAES_Key_TableֵЧ
                    encrypt_init_flag = 1;
                }
                for (int i = 0; i < (data_size / 16); i++)
                {
                    aesDecrypt(&data_temp[16 * i], chainCipherBlock); //AESܣݴdat棬ܾܵõ֮ǰġ
                }
#endif
                __set_PRIMASK(1);
                FLASH_Unlock();
                ret = BOOT_ProgramDatatoFlash(start_addr, data_temp, data_size);
                FLASH_Lock();
                __set_PRIMASK(0);
                if (ret == FLASH_COMPLETE)
                {
                    crc_data = crc16_ccitt((const unsigned char *)(data_temp), data_size);
                    //ٴζдFlashеݽCRCУ飬ȷдFlash
                    if (crc_data != crc16_ccitt((const unsigned char *)(start_addr), data_size))
                    {
                        SendData[3] = BOOT_ERR_WRITE_CRC;
                    }
                    else
                    {
                        SendData[3] = BOOT_ERR_SUCCESS;
                    }
                }
                else
                {
                    SendData[3] = BOOT_ERR_WRITE;
                }
            }
        }
        SendData[4] = 0xFF;
        SendData[5] = 0xFF;
        SendData[6] = 0xFF;
        SendData[7] = 0xFF;
        BOOT_SendData(SendData, 8);
        break;
    case CMD_ENTER_APP:
        OLD_CMD = CMD_ENTER_APP;
        if (FW_TYPE == FW_TYPE_BOOT)
        {
            if ((*((uint32_t *)APP_START_ADDR) != 0xFFFFFFFF))
            {
                BOOT_JumpToApplication(APP_START_ADDR);
            }
        }
        break;
    case 0xFF:
        if (OLD_CMD == CMD_TRAN_DATA)
        {
            if (((PCI & 0xF0) == 0x20) && ((CF_Index & 0xF) == (PCI & 0xF)))
            {
                CF_Index++;
                pData = &pRxMessage->Data[2];
                if ((data_index + 6) <= data_size)
                {
                    for (i = 0; i < 6; i++)
                    {
                        data_temp[data_index++] = *pData++;
                    }
                }
                else
                {
                    while (data_index < data_size)
                    {
                        data_temp[data_index++] = *pData++;
                    }
                }
            }
        }
        break;
    default:
        break;
    }
}
/*********************************END OF FILE**********************************/

